@@ -14,7 +14,7 @@ from typing import Dict, Union, Optional, List, Tuple, Any
 
 from baseline.utils import read_config_file, str2bool, listify, import_user_module, idempotent_append
 from odin import Path
-from odin.utils.yaml import write_yaml
+from odin.utils.yaml_utils import write_yaml
 
 
 LOGGER = logging.getLogger('odin')
@@ -677,7 +677,10 @@ def generate_pipeline(  # pylint: disable=too-many-locals,too-many-branches,too-
 
 
 def get_images(
-    template_loc: Path, mead: Optional[str] = None, odin: Optional[str] = None, claim: Optional[str] = None,
+    template_loc: Path,
+    mead: Optional[str] = None,
+    odin: Optional[str] = None,
+    claim: Optional[str] = None,
 ) -> Tuple[Dict[str, str], Dict[str, str]]:
     """Get image names with a fallback to the images file."""
     defaults = read_config_file(os.path.join(template_loc, 'images.yml'))
